<template>
    <div class="product-row d-flex flex-wrap align-items-center justify-content-between">
        <div class="product-image col-3">
            <img :src="resolvedImageUrl" :alt="`${props.product.name} image`" class="img-fluid" />
        </div>
        <div class="product-data col-5 d-flex flex-column">
            <div>
                <div class="cart-product-name">{{ props.product.name }}</div>
                <div v-if="props.product.variant" class="cart-variant-name">Talle {{ props.product.variant }}</div>
            </div>
            <a class="button-delete-item mt-auto" @click="removeItem(props.product.id, props.product.variantId)"
                >Eliminar</a
            >
        </div>
        <div class="product-price col-4 text-end">
            <span class="cart-product-price">
                <span class="cart-product-quantity">({{ props.product.quantity }})</span>
                ${{ formatCurrency(props.product.price) }}
            </span>
        </div>
    </div>
</template>

<script setup>
import { computed } from "vue"; // Importa computed
import { cartStore } from "../../js/stores/cart.js";
import { useShippingStore } from "../../js/stores/shippingStore.js";

const props = defineProps({
    product: {
        type: Object,
        required: true,
    },
});

const store = cartStore();
const shippingStore = useShippingStore();

const removeItem = (productId, variantId) => {
    store.removeItem(productId, variantId);
    // shippingStore.calculateShipping();
};

// Método para construir la URL de la imagen
const resolveImageUrl = (file) => {
    if (file === null) {
        return "/build/images/web/nophoto.png";
    }
    const mediaUrl = "/photos"; // Ajusta esto según tu configuración

    // Extrae el directorio y el nombre del archivo
    const dir = file.substring(0, file.lastIndexOf("/"));
    const baseName = file.substring(file.lastIndexOf("/") + 1);

    // Construye la nueva URL
    return `${mediaUrl}/${dir}/list_${baseName}`;
};

// Computed property para la URL de la imagen resuelta
const resolvedImageUrl = computed(() => resolveImageUrl(props.product.image));

const formatCurrency = (value) => {
    return new Intl.NumberFormat("es-AR", {
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    }).format(value);
};
</script>

<style lang="scss">
@use "../../scss/variables" as vars;

.product-row {
    padding: 25px 0;
    border-bottom: 1px dashed vars.$gris-just;
}

.cart-product-name {
    color: vars.$negro-just;
    font-size: 12px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.cart-variant-name {
    color: vars.$negro-just;
    font-size: 8px;
    text-transform: uppercase;
    padding-bottom: 5px;
}

.cart-product-price {
    color: vars.$negro-just;
    font-size: 16px;
    font-family: "Plus Jakarta Sans", sans-serif;
    font-weight: 600;
}

.product-image {
    img {
        border-radius: 5px;
    }
}

.product-data {
    padding-left: 25px;
    font-family: "Plus Jakarta Sans", sans-serif;
    height: 115px;

    .cart-product-name {
        font-size: 19px;
        font-weight: 300;
    }

    .cart-variant-name {
        font-size: 13px;
        text-transform: uppercase;
        font-weight: 600;
    }

    .cart-product-delete {
        align-content: flex-end;
    }
}

.product-price {
    height: 123px;
    align-content: flex-end;
}

.cart-product-quantity {
    font-size: 14px;
}

.delete-container {
    display: block;
}

.button-delete-item {
    font-size: 13px;
    font-weight: 700;
    text-transform: uppercase;
}
</style>
